%define anolis_release 1

%global githubname QATzip
%global libqatzip_soversion 3

Name:           qatzip
Version:        1.2.0
Release:        %{anolis_release}%{?dist}
Summary:        Intel QuickAssist Technology (QAT) QATzip Library
License:        BSD-3-Clause
URL:            https://github.com/intel/%{githubname}
Source0:        %{url}/archive/%{version}/%{name}-%{version}.tar.gz

BuildRequires:  gcc >= 4.8.5
BuildRequires:  zlib-devel >= 1.2.7
BuildRequires:  qatlib-devel >= 23.08.0
BuildRequires:  autoconf automake libtool make lz4-devel

# The purpose of the package is to support hardware that only exists on x86_64 platforms
ExclusiveArch:  x86_64

%description
Intel QATzip is a software library designed to provide hardware-assisted
compression and decompression acceleration for data processing applications.
It works in conjunction with Intel QuickAssist Technology (QAT) hardware,
which is a specialized hardware accelerator for cryptographic and compression
workloads. QATzip supports a variety of compression algorithms, including GZIP,
DEFLATE, and LZ77. These algorithms can be used to reduce the size of data,
improve network and storage efficiency, and increase data transfer rates. 
The library provides an API that enables developers to integrate the compression
and decompression features into their applications easily. QATzip is often used
in cloud computing, big data, and network applications that require fast data
processing, low latency, and efficient data transfer. For example, it can be used
to compress data before sending it over a network, reducing the bandwidth required
and improving the response time. It can also be used to compress data before storing
it, reducing the storage requirements and improving the retrieval time. In summary,
Intel QATzip is a powerful software library that provides hardware-accelerated
compression and decompression capabilities to improve the performance, efficiency,
and throughput of data processing applications.

%package        libs
Summary:        Libraries for the qatzip package

%description    libs
This package contains libraries for applications to use
the QATzip APIs.

%package        devel
Summary:        Development components for the libqatzip package
Requires:       %{name}-libs%{?_isa} = %{version}-%{release}

%description    devel
This package contains headers and libraries required to build
applications that use the QATzip APIs.

%package        doc
Summary:        Documentation files for %{name}
Requires:       %{name} = %{EVR}
BuildArch:      noarch

%description    doc
The %{name}-doc package contains documentation files for %{name}.

%prep
%autosetup -n %{githubname}-%{version}

%build
%set_build_flags

autoreconf -vif
./configure \
    --bindir=%{_bindir} \
    --libdir=%{_libdir} \
    --includedir=%{_includedir} \
    --mandir=%{_mandir} \
    --prefix=%{_prefix} \
    --enable-symbol

%make_build

%install
%make_install
rm %{buildroot}/%{_libdir}/libqatzip.a
rm %{buildroot}/%{_libdir}/libqatzip.la
rm -vf %{buildroot}%{_mandir}/*.pdf

%generate_compatibility_deps
# Check section is not available for these functional and performance tests require special hardware.

%files
%license LICENSE*
%{_mandir}/man1/qzip.1*
%{_bindir}/qzip
%{abidir}/qzip-option.list
%{_bindir}/qatzip-test

%files libs
%dir %{abidir}
%license LICENSE*
%{_libdir}/libqatzip.so.%{libqatzip_soversion}*
%{abidir}/libqatzip.dump

%files devel
%doc docs/QATzip-man.pdf
%{_includedir}/qatzip.h
%{_libdir}/libqatzip.so
%{_libdir}/pkgconfig/*.pc

%changelog
* Wed Dec 04 2024 Zelin Deng <zelin.deng@linux.alibaba.com> - 1.2.0
- Update to qatzip v1.2.0
